@@ -1,7 +1,11 @@
 package XS::libunievent;
 use XS::Loader;
 
-our $VERSION = '1.0.2';
+use Net::SockAddr;
+use XS::libuv;
+use XS::libcares;
+
+our $VERSION = '1.0.3';
 
 XS::Loader::load_noboot();
 
